@@ -1,4 +1,4 @@
-# $Id: Checkout.pm 853 2005-09-21 01:14:42Z claco $
+# $Id: Checkout.pm 870 2005-09-27 00:35:53Z claco $
 package Catalyst::Helper::Controller::Handel::Checkout;
 use strict;
 use warnings;
@@ -849,6 +849,19 @@ __complete__
     <tr>
         <td colspan="5" height="5">&nbsp;</td>
     </tr>
+    <tr>
+        <td align="right">Order Number:</td>
+        <td align="left">[% HTML.escape(order.number) %]</td>
+        <td colspan="3"></td>
+    </tr>
+    <tr>
+        <td align="right">Order Created:</td>
+        <td align="left">[% HTML.escape(order.updated) %]</td>
+        <td colspan="3"></td>
+    </tr>
+    <tr>
+        <td colspan="5" height="5">&nbsp;</td>
+    </tr>
     <tr>
         <td align="right">First Name:</td>
         <td align="left">[% HTML.escape(order.billtofirstname) %]</td>
@@ -1025,6 +1038,16 @@ qualified package name:
 In all three cases everything before M{odel)|C(ontroller) will be stripped and the class CartModel
 will be used.
 
+By default, the code generated by this helper requires Data::FormValidator 4.00 or greater
+and HTML::FillInForm 1.04 or greater to be installed for it's form validation. If you don't
+want to install Data::FormValidator or HTML::FillInForm, simply comment out this line in
+the generated controller class:
+
+    use Data::FormValidator 4.00;
+    use HTML::FillInForm 1.04;
+
+The code is designed to work without Data::FormValidator 4.00 and/or HTML::FillInForm 1.04 installed.
+
 =head1 METHODS
 
 =head2 mk_compclass
