@@ -1,4 +1,4 @@
-# $Id: Order.pm 844 2005-09-21 00:17:51Z claco $
+# $Id: Order.pm 870 2005-09-27 00:35:53Z claco $
 package Catalyst::Helper::Controller::Handel::Order;
 use strict;
 use warnings;
@@ -477,6 +477,14 @@ qualified package name:
 In all three cases everything before M{odel)|C(ontroller) will be stripped and the class OrderModel
 will be used.
 
+By default, the code generated by this helper requires Data::FormValidator 4.00 or greater
+to be installed for it's form validation. If you don't want to install Data::FormValidator,
+simply comment out this line in the generated controller class:
+
+    use Data::FormValidator 4.00;
+
+The code is designed to work without Data::FormValidator 4.00 installed.
+
 =head1 METHODS
 
 =head2 mk_compclass
