@@ -1,4 +1,4 @@
-# $Id: Item.pm 478 2005-03-22 00:50:54Z claco $
+# $Id: Item.pm 768 2005-09-05 02:25:24Z claco $
 package Handel::Cart::Item;
 use strict;
 use warnings;
@@ -13,12 +13,13 @@ BEGIN {
 __PACKAGE__->table('cart_items');
 __PACKAGE__->autoupdate(1);
 __PACKAGE__->iterator_class('Handel::Iterator');
-__PACKAGE__->columns( All => qw(id cart sku quantity price description) );
-__PACKAGE__->columns( Essential => qw(id cart sku quantity price description) );
-__PACKAGE__->add_constraint( 'quantity', quantity => \&constraint_quantity );
-__PACKAGE__->add_constraint( 'price',    price    => \&constraint_price );
-__PACKAGE__->add_constraint( 'id',       id       => \&constraint_uuid );
-__PACKAGE__->add_constraint( 'cart',     cart     => \&constraint_uuid );
+__PACKAGE__->columns(All => qw(id cart sku quantity price description));
+__PACKAGE__->columns(Essential => qw(id cart sku quantity price description));
+__PACKAGE__->has_a(price => 'Handel::Currency');
+__PACKAGE__->add_constraint('quantity', quantity => \&constraint_quantity);
+__PACKAGE__->add_constraint('price',    price    => \&constraint_price);
+__PACKAGE__->add_constraint('id',       id       => \&constraint_uuid);
+__PACKAGE__->add_constraint('cart',     cart     => \&constraint_uuid);
 
 sub new {
     my ($self, $data) = @_;
@@ -34,17 +35,6 @@ sub new {
     return $self->construct($data);
 };
 
-sub price {
-    my ($self, $price) = @_;
-
-    if (defined $price) {
-        $self->_price($price);
-        return undef;
-    } else {
-        return Handel::Currency->new($self->_price);
-    };
-};
-
 sub total {
     my $self = shift;
     return Handel::Currency->new($self->quantity * $self->price);
