@@ -1,16 +1,11 @@
-# $Id: Plugin.pm 1478 2006-10-17 01:28:01Z claco $
+# $Id: Plugin.pm 768 2005-09-05 02:25:24Z claco $
 package Handel::Checkout::Plugin;
 use strict;
 use warnings;
 
-BEGIN {
-    use Handel::L10N qw/translate/;
-    use Carp qw/cluck/;
-};
-
 sub new {
     my ($class, $ctx) = @_;
-    my $self = bless {}, $class;
+    my $self = bless {}, ref $class || $class;
 
     $self->init($ctx);
 
@@ -18,21 +13,19 @@ sub new {
 };
 
 sub init {
-    return;
+
 };
 
 sub setup {
-    return;
+
 };
 
 sub teardown {
-    return;
+
 };
 
 sub register {
-    cluck translate('PLUGIN_HAS_NO_REGISTER');
-
-    return;
+    warn "Attempt to register plugin that hasn't defined 'register'!";
 };
 
 sub name {
@@ -53,25 +46,25 @@ Handel::Checkout::Plugin - Base module for Handle::Checkout plugins
     package MyPackage::FaxOrder;
     use Handel::Constants qw(:checkout);
     use base 'Handel::Checkout::Plugin';
-    
+
     sub register {
         my ($self, $ctx) = @_;
 
         $ctx->add_handler(CHECKOUT_PHASE_DELIVER, \&deliver);
     };
-    
+
     sub deliver {
         my ($self, $ctx) = @_;
-    
+
         ...
-    
+
         return CHECKOUT_HANDLER_OK;
     };
 
 =head1 DESCRIPTION
 
-Handel::Checkout::Plugin is the base module for all checkout pipeline plugins
-used in Handel::Checkout.
+C<Handel::Checkout::Plugin> is the base module for all checkout pipeline
+plugins used in C<Handel::Checkout>.
 
 =head1 CONSTRUCTOR
 
@@ -115,13 +108,13 @@ A plugin can register any number of methods with any number of phases.
 
 Each time a checkout pipeline is processed, the C<setup> method is called
 on all registered plugins to allow each plugin to perform any
-necessary preparation before its registered handler subs are called.
+necessary preperation before its registered handler subs are called.
 
 =head2 teardown
 
 Each time a checkout pipeline is finished being processed, the
 C<teardown> method is called on all registered plugins to allow each plugin
-to perform any cleanup it may need to do.
+to performa any cleanup it may need to do.
 
 =head2 name
 
