@@ -1,4 +1,4 @@
-# $Id: Exception.pm 478 2005-03-22 00:50:54Z claco $
+# $Id: Exception.pm 768 2005-09-05 02:25:24Z claco $
 package Handel::Exception;
 use strict;
 use warnings;
@@ -73,6 +73,34 @@ sub new {
         -text => 'The tag is out of scope or missing required child tags', @_ );
 };
 
+package Handel::Exception::Order;
+use strict;
+use warnings;
+
+BEGIN {
+    use base 'Handel::Exception';
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'An error occurred while while creating or validating the current order', @_ );
+};
+
+package Handel::Exception::Checkout;
+use strict;
+use warnings;
+
+BEGIN {
+    use base 'Handel::Exception';
+};
+
+sub new {
+    my $class = shift;
+    return $class->SUPER::new(
+        -text => 'An error occurred during the checkout process', @_ );
+};
+
 1;
 __END__
 
